package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbExamSimulateInfo;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 考试、模拟考试考生详情Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-11
 */
public interface TbExamSimulateInfoMapper
{
    /**
     * 查询考试、模拟考试考生详情
     *
     * @param examSimulateInfoId 考试、模拟考试考生详情主键
     * @return 考试、模拟考试考生详情
     */
    public TbExamSimulateInfo selectTbExamSimulateInfoByExamSimulateInfoId(Long examSimulateInfoId);

    /**
     * 查询考试、模拟考试考生详情列表
     *
     * @param tbExamSimulateInfo 考试、模拟考试考生详情
     * @return 考试、模拟考试考生详情集合
     */
    public List<TbExamSimulateInfo> selectTbExamSimulateInfoList(TbExamSimulateInfo tbExamSimulateInfo);

    /**
     * 新增考试、模拟考试考生详情
     *
     * @param tbExamSimulateInfo 考试、模拟考试考生详情
     * @return 结果
     */
    public int insertTbExamSimulateInfo(TbExamSimulateInfo tbExamSimulateInfo);

    /**
     * 修改考试、模拟考试考生详情
     *
     * @param tbExamSimulateInfo 考试、模拟考试考生详情
     * @return 结果
     */
    public int updateTbExamSimulateInfo(TbExamSimulateInfo tbExamSimulateInfo);

    /**
     * 删除考试、模拟考试考生详情
     *
     * @param examSimulateInfoId 考试、模拟考试考生详情主键
     * @return 结果
     */
    public int deleteTbExamSimulateInfoByExamSimulateInfoId(Long examSimulateInfoId);

    /**
     * 批量删除考试、模拟考试考生详情
     *
     * @param examSimulateInfoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbExamSimulateInfoByExamSimulateInfoIds(Long[] examSimulateInfoIds);

    /**
     * 查询模拟考试考生及考试信息
     *
     * @param params 参数
     * @return 结果
     */
    public Map<String,Object> getSimulateSubjectAllInfo(Map<String,Object> params);

    /**
     * 计算总分
     *
     * @param examSimulateInfoId 考试、模拟考试考生详情主键
     * @return 结果
     */
    public BigDecimal countTotalScore(Long examSimulateInfoId);

    /**
     * 查询正式考试考生及考试信息
     *
     * @param params 参数
     * @return 结果
     */
    public Map<String,Object> getFormalSubjectAllInfo(Map<String,Object> params);

    /**
     * 查询最大的考台编号
     *
     * @param examId 考试ID
     * @return 结果
     */
    public Integer selectMaxExamPlatformNumber(Long examId);

    /**
     * 查询考试、模拟考试考生详情（保留整数）
     *
     * @param examSimulateInfoId 考试、模拟考试考生详情主键
     * @return 考试、模拟考试考生详情
     */
    public TbExamSimulateInfo selectTbExamSimulateInfoByExamSimulateInfoIdRetain(Long examSimulateInfoId);

    /**
     * 模拟考试上次考试状态
     *
     * @param params 参数
     * @return 结果
     */
    public Map<String,Object> getSimulateSubjectUp(Map<String,Object> params);

    /**
     * 查询考试详情（用户ID、考试ID）
     *
     * @param memberUserId 用户ID
     * @param examId 考试报名ID
     * @return 考试报名
     */
    public TbExamSimulateInfo getByMemberUserId(@Param("memberUserId") Long memberUserId,
                                                 @Param("examId") Long examId);
}
