package com.ruoyi.hezhi.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.hezhi.domain.TbExamSimulateInfo;
import com.ruoyi.hezhi.service.ITbExamSimulateInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 考试、模拟考试考生详情Controller
 *
 * @author ruoyi
 * @date 2024-11-11
 */
@RestController
@RequestMapping("/hezhi/examSimulateInfo")
public class TbExamSimulateInfoController extends BaseController
{
    @Autowired
    private ITbExamSimulateInfoService tbExamSimulateInfoService;

    /**
     * 查询考试、模拟考试考生详情列表
     */
    @PreAuthorize("@ss.hasPermi('hezhi:examSimulateInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbExamSimulateInfo tbExamSimulateInfo)
    {
        startPage();
        List<TbExamSimulateInfo> list = tbExamSimulateInfoService.selectTbExamSimulateInfoList(tbExamSimulateInfo);
        return getDataTable(list);
    }

    /**
     * 导出考试、模拟考试考生详情列表
     */
    @PreAuthorize("@ss.hasPermi('hezhi:examSimulateInfo:export')")
    @Log(title = "考试、模拟考试考生详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbExamSimulateInfo tbExamSimulateInfo)
    {
        List<TbExamSimulateInfo> list = tbExamSimulateInfoService.selectTbExamSimulateInfoList(tbExamSimulateInfo);
        ExcelUtil<TbExamSimulateInfo> util = new ExcelUtil<TbExamSimulateInfo>(TbExamSimulateInfo.class);
        util.exportExcel(response, list, "考试、模拟考试考生详情数据");
    }

    /**
     * 获取考试、模拟考试考生详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('hezhi:examSimulateInfo:query')")
    @GetMapping(value = "/{examSimulateInfoId}")
    public AjaxResult getInfo(@PathVariable("examSimulateInfoId") Long examSimulateInfoId)
    {
        return success(tbExamSimulateInfoService.selectTbExamSimulateInfoByExamSimulateInfoId(examSimulateInfoId));
    }

    /**
     * 新增考试、模拟考试考生详情
     */
    @PreAuthorize("@ss.hasPermi('hezhi:examSimulateInfo:add')")
    @Log(title = "考试、模拟考试考生详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbExamSimulateInfo tbExamSimulateInfo)
    {
        return toAjax(tbExamSimulateInfoService.insertTbExamSimulateInfo(tbExamSimulateInfo));
    }

    /**
     * 修改考试、模拟考试考生详情
     */
    @PreAuthorize("@ss.hasPermi('hezhi:examSimulateInfo:edit')")
    @Log(title = "考试、模拟考试考生详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbExamSimulateInfo tbExamSimulateInfo)
    {
        return toAjax(tbExamSimulateInfoService.updateTbExamSimulateInfo(tbExamSimulateInfo));
    }

    /**
     * 删除考试、模拟考试考生详情
     */
    @PreAuthorize("@ss.hasPermi('hezhi:examSimulateInfo:remove')")
    @Log(title = "考试、模拟考试考生详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{examSimulateInfoIds}")
    public AjaxResult remove(@PathVariable Long[] examSimulateInfoIds)
    {
        return toAjax(tbExamSimulateInfoService.deleteTbExamSimulateInfoByExamSimulateInfoIds(examSimulateInfoIds));
    }
}
